@@ -144,6 +144,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 task::spawn(async move {
                     let subscription = internal_ctx.payment_processing_subscription.clone();
                     while subscription.client().is_running() {
+                        println!("pulling payment processing messages");
                         match subscription.get_messages::<Message>().await {
                             Ok(messages) => {
                                 for (result, ack_id) in messages {
@@ -167,6 +168,8 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                             Err(e) => eprintln!("Failed to pull PubSub messages: {}", e),
                         }
                     }
+
+                    println!("done pulling payment processing messages");
                 });
             }
 
